@@ -577,7 +577,7 @@ getDataCensus <- function(task.type="classif",
               V8="marital_status",
               V9="major_industry_code",
               V10="major_occupation_code",
-              V11="mace",
+              V11="race",
               V12="hispanic_origin",
               V13="sex",
               V14="member_of_a_labor_union",
@@ -653,7 +653,7 @@ getDataCensus <- function(task.type="classif",
                          "industry_code",
                          "major_industry_code",
                          "sex",
-                         "mace",
+                         "race",
                          "hispanic_origin",
                          "detailed_household_and_family_stat",
                          "detailed_household_summary_in_household",
@@ -663,7 +663,7 @@ getDataCensus <- function(task.type="classif",
                          "income_class")
   cat.features.full <- c("class_of_worker","industry_code","occupation_code",
                          "education","enrolled_in_edu_inst_last_wk","marital_status",
-                         "major_industry_code","major_occupation_code","mace",
+                         "major_industry_code","major_occupation_code","race",
                          "hispanic_origin","sex","member_of_a_labor_union",
                          "reason_for_unemployment","full_or_part_time_employment_stat","tax_filer_status",
                          "region_of_previous_residence","state_of_previous_residence","detailed_household_and_family_stat",
